@@ -58,7 +58,7 @@ wd = '/Users/songweizhi/Desktop/assess_linkages'
 
 ########## reference to cluster ##########
 
-drep_ani_cutoff             = 97
+drep_ani_cutoff             = 95
 drep_cdb_file               = '%s/file_in/Cdb_%s.csv'                                       % (wd, drep_ani_cutoff)
 ref_to_strain_file          = '%s/file_in/ref_to_strain.txt'                                % wd
 
@@ -92,15 +92,59 @@ total_query_mag_num         = 97
 
 ########## assessment results ##########
 
-MarkerMAG_linkages          = '%s/GI_0602_128_60_60_good_linkages_by_genome.txt'             % wd
+MarkerMAG_linkages          = '%s/GI_0719_128_45_45_1200_diff10_linkages_by_genome.txt'             % wd
 mlen = '45'
 #MarkerMAG_linkages          = '/Users/songweizhi/Desktop/test_filter/GI_0524_128_%s_%s_stats_combined_filtered.txt' % (mlen, mlen)
 
 #MarkerMAG_linkages          = '/Users/songweizhi/Desktop/tunning_rd2_up/stats_GapFilling_gnm_filtered.txt'
 linkages_from_rd1           = False
 
+MarkerMAG_linkages          = '/Users/songweizhi/Desktop/tunning_rd1_GI/stats_combined_filtered.txt'
+linkages_from_rd1           = True
 
 '''
+GI_0719_128_45_45_1200_linkages_by_genome.txt	Rd_1	|	59	59	0	0	59/59(100.0)	|	19	19	0	0	0	19/97(19.59)	19/19(100.0)
+GI_0719_128_45_45_1200_linkages_by_genome.txt	Rd_2	|	9	9	0	0	9/9(100.0)	    |	7	7	0	0	0	7/97(7.22)	    7/7(100.0)
+GI_0719_128_45_45_1200_linkages_by_genome.txt	Both	|	68	68	0	0	68/68(100.0)	|	26	26	0	0	0	26/97(26.8)	    26/26(100.0)
+
+GI_0719_128_45_45_1200_diff10_linkages_by_genome.txt	Rd_1	|	108	96	0	12	96/108(88.89)	|	20	18	0	0	2	18/97(18.56)	18/20(90.0)
+GI_0719_128_45_45_1200_diff10_linkages_by_genome.txt	Rd_2	|	14	8	3	3	8/11(72.73)	    |	6	5	0	1	0	5/97(5.15)	    5/6(83.33)
+GI_0719_128_45_45_1200_diff10_linkages_by_genome.txt	Both	|	122	104	3	15	104/119(87.39)	|	26	23	0	1	2	23/97(23.71)	23/26(88.46)
+
+
+GI_0719_128_60_60_1200_linkages_by_genome.txt	Rd_1	|	56	56	0	0	56/56(100.0)	|	18	18	0	0	0	18/97(18.56)	18/18(100.0)
+GI_0719_128_60_60_1200_linkages_by_genome.txt	Rd_2	|	6	6	0	0	6/6(100.0)	    |	5	5	0	0	0	5/97(5.15)	    5/5(100.0)
+GI_0719_128_60_60_1200_linkages_by_genome.txt	Both	|	62	62	0	0	62/62(100.0)	|	23	23	0	0	0	23/97(23.71)	23/23(100.0)
+
+GI_0719_128_60_60_1200_diff10_linkages_by_genome.txt	Rd_1	|	88	87	0	1	87/88(98.86)	|	19	18	0	0	1	18/97(18.56)	18/19(94.74)
+GI_0719_128_60_60_1200_diff10_linkages_by_genome.txt	Rd_2	|	12	8	2	2	8/10(80.0)	    |	5	5	0	0	0	5/97(5.15)	    5/5(100.0)
+GI_0719_128_60_60_1200_diff10_linkages_by_genome.txt	Both	|	100	95	2	3	95/98(96.94)	|	24	23	0	0	1	23/97(23.71)	23/24(95.83)
+
+
+GI_0717_128_45_45_1500_linkages_by_genome.txt	Rd_1	|	11	11	0	0	11/11(100.0)	|	9	9	0	0	0	9/97(9.28)	9/9(100.0)
+GI_0717_128_45_45_1500_linkages_by_genome.txt	Rd_2	|	2	0	0	2	0/2(0.0)	|	1	0	0	1	0	0/97(0.0)	0/1(0.0)
+GI_0717_128_45_45_1500_linkages_by_genome.txt	Both	|	13	11	0	2	11/13(84.62)	|	10	9	0	1	0	9/97(9.28)	9/10(90.0)
+
+GI_0717_128_60_60_1500_linkages_by_genome.txt	Rd_1	|	10	10	0	0	10/10(100.0)	|	8	8	0	0	0	8/97(8.25)	8/8(100.0)
+GI_0717_128_60_60_1500_linkages_by_genome.txt	Rd_2	|	3	0	0	3	0/3(0.0)	|	2	0	0	2	0	0/97(0.0)	0/2(0.0)
+GI_0717_128_60_60_1500_linkages_by_genome.txt	Both	|	13	10	0	3	10/13(76.92)	|	10	8	0	2	0	8/97(8.25)	8/10(80.0)
+
+
+GI_0715_128_45_45_linkages_by_genome.txt	Rd_1	|	94	87	4	3	87/90(96.67)	|	25	23	0	1	1	23/97(23.71)	23/25(92.0)
+GI_0715_128_45_45_linkages_by_genome.txt	Rd_2	|	7	7	0	0	7/7(100.0)	    |	5	5	0	0	0	5/97(5.15)	    5/5(100.0)
+GI_0715_128_45_45_linkages_by_genome.txt	Both	|	101	94	4	3	94/97(96.91)	|	30	28	0	1	1	28/97(28.87)	28/30(93.33)
+
+GI_0715_128_60_60_linkages_by_genome.txt	Rd_1	|	61	61	0	0	61/61(100.0)	|	21	21	0	0	0	21/97(21.65)	21/21(100.0)
+GI_0715_128_60_60_linkages_by_genome.txt	Rd_2	|	6	6	0	0	6/6(100.0)	    |	5	5	0	0	0	5/97(5.15)	    5/5(100.0)
+GI_0715_128_60_60_linkages_by_genome.txt	Both	|	67	67	0	0	67/67(100.0)	|	26	26	0	0	0	26/97(26.8)	    26/26(100.0)
+
+
+
+
+GI_0630_128_60_60_linkages_by_genome.txt	Round	|	Link	Yes	NA	No	Accuracy	|	MAG	Yes	NA	No	Y/N	Recovery	Accuracy
+GI_0630_128_60_60_linkages_by_genome.txt	Rd_1	|	82	79	3	0	79/79(100.0)	|	26	26	0	0	0	26/97(26.8)	26/26(100.0)
+GI_0630_128_60_60_linkages_by_genome.txt	Rd_2	|	3	3	0	0	3/3(100.0)	    |	3	3	0	0	0	3/97(3.09)	3/3(100.0)
+GI_0630_128_60_60_linkages_by_genome.txt	Both	|	85	82	3	0	82/82(100.0)	|	29	29	0	0	0	29/97(29.9)	29/29(100.0)
 
 GI_0602_128_60_60_good_linkages_by_genome.txt	Rd_1	|	80	74	6	0	74/74(100.0)	|	23	23	0	0	0	23/97(23.71)	23/23(100.0)
 GI_0602_128_60_60_good_linkages_by_genome.txt	Rd_2	|	14	13	1	0	13/13(100.0)	|	6	5	1	0	0	5/97(5.15)	5/5(100.0)
@@ -506,83 +550,26 @@ print('%s\tBoth\t|\t%s\t%s\t%s\t%s\t%s\t|\t%s\t%s\t%s\t%s\t%s\t%s\t%s' % (prefix
 ########################################################################################################################
 
 '''
-
-########################################################################################################################
-
-# use 80_20 in round 2
-GI_0412_specific_spades_M2_85_diff_80_20	Round	|	Link	Yes	NA	No	Accuracy	|	MAG	Yes	NA	No	Y/N	Recovery	    Accuracy
-GI_0412_specific_spades_M2_85_diff_80_20	Rd_2	|	23	    21	1	1	21/22(95.45)|	18	16	1	1	0	16/97(16.49)	16/17(94.12)
-GI_0412_specific_spades_M2_85_diff_75_20	Rd_2	|	26	    23	1	2	23/25(92.0)	|	17	15	1	1	0	15/97(15.46)	15/16(93.75)
-GI_0412_specific_spades_M2_85_diff_50_20	Rd_2	|	42	    37	1	4	37/41(90.24)|	17	15	1	1	0	15/97(15.46)	15/16(93.75)
-
-########################################################################################################################
+https://www.ncbi.nlm.nih.gov/pmc/articles/PMC4256179/
+A ANI cutoff score of >95% indicates that they belong to the same species. 
 
 '''
-'''
+# print(cluster_to_bin_dict['C45_0'])  # 'Refined_47', 'Refined_50'
+# print(cluster_to_bin_dict['C44_1'])  # 'Refined_56', 'Refined_34'
+#
+#
+# print(matam_16s_to_cluster_dict['3_GI_subsample_75_1732'])
+# print(matam_16s_to_cluster_dict['3_GI_subsample_100_3665'])
+#
+print('16s_to_cluster\t%s\t%s' % ('3_GI_subsample_75_1074', matam_16s_to_cluster_dict['3_GI_subsample_75_1074']))
+print('16s_to_cluster\t%s\t%s' % ('3_GI_subsample_75_1075', matam_16s_to_cluster_dict['3_GI_subsample_75_1075']))
+print('16s_to_cluster\t%s\t%s' % ('3_GI_subsample_75_1079', matam_16s_to_cluster_dict['3_GI_subsample_75_1079']))
+print('16s_to_cluster\t%s\t%s' % ('3_GI_subsample_50_663', matam_16s_to_cluster_dict['3_GI_subsample_50_663']))
+print('16s_to_cluster\t%s\t%s' % ('3_GI_subsample_75_2595', matam_16s_to_cluster_dict['3_GI_subsample_75_2595']))
+print('16s_to_cluster\t%s\t%s' % ('3_GI_subsample_75_1158', matam_16s_to_cluster_dict['3_GI_subsample_75_1158']))
 
 
-3_GI_subsample_75_1644	Refined_4	958	S1	Wrong
-3_GI_subsample_75_1159	Refined_4	878	S1	Wrong
-
-3_GI_subsample_100_1336	Refined_4	958	S1	Correct
-3_GI_subsample_25_345	Refined_4	958	S1	Unknown
-3_GI_subsample_75_2502	Refined_4	958	S1	Correct
-3_GI_subsample_25_763	Refined_4	958	S1	Correct
-3_GI_subsample_100_2066	Refined_4	958	S1	Correct
-3_GI_subsample_75_69	Refined_4	958	S1	Correct
-3_GI_subsample_10_173	Refined_4	958	S1	Unknown
-3_GI_subsample_100_3364	Refined_4	958	S1	Correct
-3_GI_subsample_75_1008	Refined_4	958	S1	Correct
-3_GI_subsample_25_565	Refined_4	958	S1	Correct
-3_GI_subsample_75_988	Refined_4	958	S1	Unknown
-3_GI_subsample_100_2322	Refined_4	929	S1	Correct
-3_GI_subsample_50_2029	Refined_4	927	S1	Unknown
-3_GI_subsample_25_913	Refined_4	926	S1	Unknown
-3_GI_subsample_75_2954	Refined_4	919	S1	Unknown
-3_GI_subsample_75_2742	Refined_4	919	S1	Correct
-3_GI_subsample_50_1564	Refined_4	898	S1	Correct
-3_GI_subsample_75_2408	Refined_4	888	S1	Correct
-3_GI_subsample_100_3244	Refined_4	888	S1	Correct
-3_GI_subsample_25_762	Refined_4	888	S1	Correct
-3_GI_subsample_100_3779	Refined_4	849	S1	Correct
-3_GI_subsample_75_2776	Refined_4	836	S1	Correct
-
-Refined_4               C46_1
-
-3_GI_subsample_75_1644  C45_0
-3_GI_subsample_75_1159  C44_1
-
-3_GI_subsample_75_1644	3_GI_subsample_100_1336	98.442	1476
-3_GI_subsample_75_1159	3_GI_subsample_75_2502	97.736	1369
-3_GI_subsample_75_1159	3_GI_subsample_25_763	99.139  697
-3_GI_subsample_75_1159	3_GI_subsample_100_2066	97.450	1412
+print('cluster_to_bin\t%s\t%s' % ('C49_0', cluster_to_bin_dict.get('C49_0', {})))
+print('cluster_to_bin\t%s\t%s' % ('C44_1', cluster_to_bin_dict.get('C44_1', {})))
 
 
-3_GI_subsample_75_1159
-3_GI_subsample_75_1159	3_GI_subsample_100_1336	98.060	1495
-3_GI_subsample_75_1159	3_GI_subsample_75_2502	97.736	1369
-3_GI_subsample_75_1159	3_GI_subsample_75_1644	99.119
-
-
-3_GI_subsample_75_1644	Refined_4	958	S1	Wrong
-3_GI_subsample_75_1644	3_GI_subsample_100_1336	98.442	1476
-3_GI_subsample_75_1644	3_GI_subsample_75_2502	98.028	1369	24
-3_GI_subsample_75_1644	3_GI_subsample_25_763	99.283	697	
-3_GI_subsample_75_1644	3_GI_subsample_100_2066	97.678	1421
-3_GI_subsample_75_1644	3_GI_subsample_75_69	98.252	1373
-
-3_GI_subsample_75_988	3_GI_subsample_100_1336	99.094	1214
-3_GI_subsample_75_988	3_GI_subsample_75_2502	98.848	1215
-3_GI_subsample_75_988	3_GI_subsample_25_763	99.283	697
-3_GI_subsample_75_988	3_GI_subsample_100_2066	98.847
-3_GI_subsample_75_988	3_GI_subsample_75_69	99.012
-3_GI_subsample_75_988	3_GI_subsample_100_3364	98.848
-
-
-
-
-
-
-'''
-print(cluster_to_bin_dict['C45_0'])  # 'Refined_47', 'Refined_50'
-print(cluster_to_bin_dict['C44_1'])  # 'Refined_56', 'Refined_34'
